# Handy Tools

## [![Build Status](https://travis-ci.com/katoozi/django-handytools.svg?token=zy2qCzh3h5SeBZfK4QFa&branch=master)](https://travis-ci.com/katoozi/django-handytools)

## Handy Tools For Your Django Project

### provided tools: models, utils, context processors, templates, template tags

## install

`pip install django-handytools`

> consider --user option
